@@ -11,6 +11,13 @@ def kd(i, j):
     '''
     return 1.0 if i == j else 0.0
 
+def mesh(a, b, n):
+    x, w = roots_legendre(n)
+    x *= (b - a)/2
+    x += (b + a)/2
+    w *= (b - a)/2
+    return x, w
+
 
 def log_mesh(a, b, n):
     '''
@@ -27,11 +34,15 @@ def log_mesh(a, b, n):
 
 
 class Mesh:
-    def __init__(self, a, b, n):
+    def __init__(self, a, b, n, log=True):
         self.lower_bound = a
         self.upper_bound = b
         self.size = n
-        self.nodes, self.weights = log_mesh(self.lower_bound, self.upper_bound, self.size)
+        if log:
+            self.nodes, self.weights = log_mesh(self.lower_bound, self.upper_bound, self.size)
+        else:
+            self.nodes, self.weights = mesh(self.lower_bound, self.upper_bound,
+                    self.size)
 
 
 def ft_matrix_gen(pot, l, lp, p, r, wr):
@@ -47,4 +58,4 @@ def ft_matrix_gen(pot, l, lp, p, r, wr):
         for ((j, rj), wj) in zip(enumerate(r), wr):
             A[i, j] = 2/np.pi * wj * rj**2 * spherical_jn(l, pi*rj)
             B[j, i] = pot(rj) * spherical_jn(lp, pi*rj)
-    return np.matmul(A, B)
\ No newline at end of file
+    return np.matmul(A, B)
